@@ -22,20 +22,20 @@ class TestFileCompressor(unittest.TestCase):
         self.series = self.df["DeviceType"]
 
     def test_get_dataset_project_hash(self):
-        hash = get_dataset_project_hash(
+        obj_hash = get_dataset_project_hash(
             dataset=self.series,
             project=self.Project(),
         )
-        self.assertIsInstance(hash, str)
+        self.assertIsInstance(obj_hash, str)
 
     def test_get_dataset_hash(self):
-        hash = get_dataset_hash(
+        obj_hash = get_dataset_hash(
             dataset=self.series,
         )
-        self.assertIsInstance(hash, str)
+        self.assertIsInstance(obj_hash, str)
 
     def test_get_project_hash(self):
-        hash = get_project_hash(
+        obj_hash = get_project_hash(
             project=self.Project(),
         )
-        self.assertIsInstance(hash, str)
+        self.assertIsInstance(obj_hash, str)
